import{c as m,a as t,f as l}from"../chunks/CjZGm4I-.js";import{w as f,x as i}from"../chunks/QnYduk6G.js";import{s as p}from"../chunks/CelXzvVb.js";import{h as c,s as _}from"../chunks/9BfctgED.js";import{l as u}from"../chunks/Bya4pnxT.js";const d=!0,h=!1,k=Object.freeze(Object.defineProperty({__proto__:null,prerender:d,ssr:h},Symbol.toStringTag,{value:"Module"}));var v=l('<link rel="icon" type="image/svg+xml"/>');function O(o,a){var e=m();c("12qhfyh",n=>{var r=v();i(()=>_(r,"href",u)),t(n,r)});var s=f(e);p(s,()=>a.children),t(o,e)}export{O as component,k as universal};
