import{d as Y,h as R,a1 as $,E as j,a2 as C,a3 as F,a4 as V,a5 as Z,a6 as T,V as y,Z as q,D as P,C as v,a as z,F as I,a7 as G,a8 as E,a9 as H,aa as m,ab as J,ac as N,T as Q,ad as W,A as X,ae as k,af as A,ag as D,ah as _,S as L,ai as B,aj as ee,u as re,ak as ne,al as se,am as ie,an as ue,ao as te,ap as ae}from"./QnYduk6G.js";import{B as fe}from"./DUiGLlN0.js";import{s as le,g as oe}from"./DF7JV_1b.js";function Pe(e,r,s=!1){R&&$();var n=new fe(e),i=s?j:0;function t(f,a){if(R){const b=C(e)===F;if(f===b){var l=V();Z(l),n.anchor=l,T(!1),n.ensure(f,a),T(!0);return}}n.ensure(f,a)}Y(()=>{var f=!1;r((a,l=!0)=>{f=!0,t(l,a)}),f||t(!1,null)},i)}let S=!1,x=Symbol();function we(e,r,s){const n=s[r]??={store:null,source:q(void 0),unsubscribe:y};if(P&&(n.source.label=r),n.store!==e&&!(x in s))if(n.unsubscribe(),n.store=e??null,e==null)n.source.v=void 0,n.unsubscribe=y;else{var i=!0;n.unsubscribe=le(e,t=>{i?n.source.v=t:I(n.source,t)}),i=!1}return e&&x in s?oe(e):v(n.source)}function me(e,r){return e.set(r),r}function xe(){const e={};function r(){z(()=>{for(var s in e)e[s].unsubscribe();G(e,x,{enumerable:!1,value:!0})})}return[e,r]}function Ee(e,r,s){return e.set(s),r}function ce(e){var r=S;try{return S=!1,[e(),S]}finally{S=r}}const pe={get(e,r){if(!e.exclude.includes(r))return e.props[r]},set(e,r){return P&&ae(`${e.name}.${String(r)}`),!1},getOwnPropertyDescriptor(e,r){if(!e.exclude.includes(r)&&r in e.props)return{enumerable:!0,configurable:!0,value:e.props[r]}},has(e,r){return e.exclude.includes(r)?!1:r in e.props},ownKeys(e){return Reflect.ownKeys(e.props).filter(r=>!e.exclude.includes(r))}};function Oe(e,r,s){return new Proxy(P?{props:e,exclude:r,name:s,other:{},to_proxy:[]}:{props:e,exclude:r},pe)}const de={get(e,r){if(!e.exclude.includes(r))return v(e.version),r in e.special?e.special[r]():e.props[r]},set(e,r,s){if(!(r in e.special)){var n=E;try{D(e.parent_effect),e.special[r]=ve({get[r](){return e.props[r]}},r,N)}finally{D(n)}}return e.special[r](s),A(e.version),!0},getOwnPropertyDescriptor(e,r){if(!e.exclude.includes(r)&&r in e.props)return{enumerable:!0,configurable:!0,value:e.props[r]}},deleteProperty(e,r){return e.exclude.includes(r)||(e.exclude.push(r),A(e.version)),!0},has(e,r){return e.exclude.includes(r)?!1:r in e.props},ownKeys(e){return Reflect.ownKeys(e.props).filter(r=>!e.exclude.includes(r))}};function ge(e,r){return new Proxy({props:e,exclude:r,special:{},version:H(0),parent_effect:E},de)}const _e={get(e,r){let s=e.props.length;for(;s--;){let n=e.props[s];if(_(n)&&(n=n()),typeof n=="object"&&n!==null&&r in n)return n[r]}},set(e,r,s){let n=e.props.length;for(;n--;){let i=e.props[n];_(i)&&(i=i());const t=m(i,r);if(t&&t.set)return t.set(s),!0}return!1},getOwnPropertyDescriptor(e,r){let s=e.props.length;for(;s--;){let n=e.props[s];if(_(n)&&(n=n()),typeof n=="object"&&n!==null&&r in n){const i=m(n,r);return i&&!i.configurable&&(i.configurable=!0),i}}},has(e,r){if(r===L||r===B)return!1;for(let s of e.props)if(_(s)&&(s=s()),s!=null&&r in s)return!0;return!1},ownKeys(e){const r=[];for(let s of e.props)if(_(s)&&(s=s()),!!s){for(const n in s)r.includes(n)||r.push(n);for(const n of Object.getOwnPropertySymbols(s))r.includes(n)||r.push(n)}return r}};function Re(...e){return new Proxy({props:e},_e)}function ve(e,r,s,n){var i=!ne||(s&se)!==0,t=(s&ee)!==0,f=(s&ue)!==0,a=n,l=!0,b=()=>(l&&(l=!1,a=f?re(n):n),a),p;if(t){var K=L in e||B in e;p=m(e,r)?.set??(K&&r in e?u=>e[r]=u:void 0)}var d,O=!1;t?[d,O]=ce(()=>e[r]):d=e[r],d===void 0&&n!==void 0&&(d=b(),p&&(i&&J(r),p(d)));var o;if(i?o=()=>{var u=e[r];return u===void 0?b():(l=!0,u)}:o=()=>{var u=e[r];return u!==void 0&&(a=void 0),u===void 0?a:u},i&&(s&N)===0)return o;if(p){var M=e.$$legacy;return(function(u,h){return arguments.length>0?((!i||!h||M||O)&&p(h?o():u),u):o()})}var w=!1,c=((s&ie)!==0?Q:W)(()=>(w=!1,o()));P&&(c.label=r),t&&v(c);var U=E;return(function(u,h){if(arguments.length>0){const g=h?v(c):i&&t?X(u):u;return I(c,g),w=!0,a!==void 0&&(a=g),u}return te&&w||(U.f&k)!==0?c.v:v(c)})}export{we as a,xe as b,me as c,Ee as d,Pe as i,ge as l,ve as p,Oe as r,Re as s};
